<?php
// $Id:

/**
 * Start page for course registration. Users are redirected to appropriate pages
 * based on their user status - student, course adviser, faculty officer, secretary
 * or super user
 *
 * @global <type> $user
 * @return <type>
 */
function pe_course_registration_home() {
  global $user;
	
  $acad_year = $user->acad_year;

	if(variable_get('do_registration', TRUE) != 1) {
		return t('No registration process.');
	}
	
	if(($acad_year->is_acad_registration_period) || ($acad_year->is_acad_registration_late)) { 
		
		if($acad_year->is_acad_registration_late) {
			drupal_set_message(t('Late registration.'));
		}
		
		if(($user->uid == 1) || ($user->is_secretary)) {
      $sec_uid = ($user->is_secretary) ? $user->uid : '';
      $output = _secretary_registration_home($sec_uid);
    }
    elseif($user->is_faculty_officer) {
      drupal_goto('pe_course/registration/'. $user->uid);
    }
    elseif($user->is_course_adviser) {
      $facor_uid = _get_og_admin_by_type('pe_group_advisers', $user->uid);
      drupal_goto('pe_course/registration/'. $facor_uid .'/'. $user->uid);
    }
    elseif($user->is_student) {			
			if((is_object($user->profileedu)) && (sizeof($user->profileedu->taxonomy))) {
				$cader_uid = _get_og_admin_by_type('pe_group_registration', $user->uid);
				$facor_uid = _get_og_admin_by_type('pe_group_advisers', $cader_uid);
				drupal_goto('pe_course/registration/'. $facor_uid .'/'. $cader_uid .'/'. $user->uid);
			} else {
				drupal_set_message(t('Your student profile has not been found. Without it you can not proceed with course registration.'));
				drupal_goto('user');
			}
    }
    else {
			//_printrbox($user);
      drupal_goto('pe_programs');
    }
	}
	else {
		$output = ($acad_year->is_acad_registration_too_early) ? t('Registration has not started yet.') : t('Registration has closed.');
		return $output;
	}
	return $output;
}


/**
 * Start page for secretaries
 *
 * @global <type> $user
 * @global <type> $conf
 * @param <type> $secretary_uid
 * @return <type>
 */
function _secretary_registration_home($secretary_uid) {
	global $user, $conf;
	
	$profiles = array(
    'profile' => array('field_firstname','field_lastname', 'field_personal_title', 'field_gender'), 
  );

  $pfields = _get_profile_fields_sql($profiles);
  
  $query = '';
  $query .= "SELECT profile.nid, ou2.uid AS faculty_officer_uid, u1.name, COUNT(DISTINCT ou1.uid) AS total_advisers, COUNT(ou4.uid) AS total_students, \n";
  $query .= implode(', ', $pfields['selects']) ."\n";
  $query .= " FROM ({users} u1, {node} profile, {og_uid} ou1, {node} n1, {node} n2) \n";
  $query .= " LEFT JOIN {og_uid} ou2 ON (ou1.nid = ou2.nid) \n";
  $query .= " LEFT JOIN {og_uid} ou3 ON (ou1.uid = ou3.uid) \n";
  $query .= " LEFT JOIN {og_uid} ou4 ON (ou3.nid = ou4.nid) \n";
  $query .= implode("\n", $pfields['joins']) ." \n";
  $query .= " WHERE ou1.is_admin <> %d \n";
  $query .= " AND n1.type = '%s' \n";
  $query .= " AND n1.nid = ou1.nid \n";
  $query .= " AND ou2.is_admin = %d \n";
  $query .= " AND ou2.uid <> n1.uid \n";
  $query .= " AND n2.type = '%s' \n";
  $query .= " AND n2.nid = ou3.nid \n";
  $query .= " AND ou3.is_admin = %d \n";
  $query .= " AND ou4.is_admin <> %d \n";
  $query .= " AND profile.type = '%s' \n";
  $query .= " AND profile.uid = ou2.uid \n";
  $query .= " AND ou2.uid = u1.uid \n";

  // secretaries can only see their course advice groups
  if(($secretary_uid > 0) && ($user->uid > 1)) {
		$query .= " AND n1.uid = %d";
	}	
  $query .= " GROUP BY ou2.uid, ou1.nid \n";
  
	$args = array();
  $args[] = 1;
  $args[] = variable_get('course_advisers_group', 'pe_group_advisers');
  $args[] = 1;
  $args[] = variable_get('course_registration_group', 'pe_group_registration');
  $args[] = 1;
  $args[] = 1;
  $args[] = 'profile';
  
	if(($secretary_uid > 0) && ($user->uid > 1)) {
		$args[] = $secretary_uid;
	}
	
	$header = array(
    array('data' => t('#')),
    array('data' => t('Name'), 'field' => 'field_lastname', 'sort' => 'asc'),
    array('data' => t('Gender'), 'field' => 'field_gender'),
    array('data' => t('Course advisers'), 'field' => 'total_advisers'),
    array('data' => t('Students'), 'field' => 'total_students'),
    array('data' => t('Operations')),
  );
  
  $show_count = variable_get('items_per_page', 100);
  $tablesort = tablesort_sql($header);
  $result = pager_query($query . $tablesort, $show_count, 0, NULL, $args);
  
  $rows = array();
  $i = 0;
  while($row = db_fetch_object($result)) {
    // mock up user profile
    $account = new stdClass();
    $account->uid = $row->faculty_officer_uid;
    $account->name = $row->name;
    $account->profile->field_lastname[0]['value'] = $row->field_lastname;
    $account->profile->field_firstname[0]['value'] = $row->field_firstname;
    $account->profile->field_personal_title[0]['value'] = _translate_personal_title($row->field_personal_title);
		
		$path = 'pe_course/registration/'. $row->faculty_officer_uid;
		$attributes = array('title' => t('View groups'));
		
  	$rows[] = array(
  		array('data' => $i + 1, 'align' => 'center'),
  		array('data' => theme('username', $account, $link = 1, $access = 1, $path, $attributes)),
  		array('data' => ($row->field_gender != '') ? theme('image', drupal_get_path('theme', $conf['theme_default']) .'/images/icon_'. drupal_strtolower($row->field_gender) .'.gif')  : '--', 'align' => 'center'),
  		array('data' => $row->total_advisers, 'align' => 'center'),
  		array('data' => $row->total_students, 'align' => 'center'), 
  		array('data' => l(t('Details'), $path, array('attributes' => $attributes)), 'align' => 'center'),		
  	);
    $i++;
  }
  
  if (count($rows) < 1) {
    $rows[] = array(array('data' => t('No faculty officers found.'), 'colspan' => count($header), 'align' => 'center'));
  }
  
  $pager = theme('pager', NULL, $show_count, 0);
  $output .= theme('table', $header, $rows);
  $output .= $pager;	
  
  return $output;
  	
}


/**
 * Start page for  faculty officers
 *
 * @global <type> $user
 * @global <type> $conf
 * @param <type> $faculty_officer
 * @return <type>
 */
function _officer_registration_home($faculty_officer) {
  global $user, $conf;

  $type = array('pe_group_advisers');
  $gids = _get_og_nids($type, (array)$faculty_officer, $manager = array()); // course advice group nids
  $uids = _get_og_uids($gids); // course adviser uids
  
  $profiles = array(
    'profile' => array('field_firstname','field_lastname', 'field_personal_title', 'field_gender'), 
  );

  $pfields = _get_profile_fields_sql($profiles);

  $db_info['field_section_id'] = _get_content_database_info('field_section_id', 'profileedu');
  $db_info['field_parent_section'] = _get_content_database_info('field_parent_section', 'pe_section');
  
  $query = '';
  $query .= " SELECT profile.nid, ou2.uid AS course_adviser_uid, u1.name, COUNT(DISTINCT n1.nid) AS total_groups, COUNT(ou1.uid) AS total_students, n3.title AS section_title, n4.title AS parent_section_title, \n";
  $query .= implode(', ', $pfields['selects']) ."\n";
  $query .= " FROM ({users} u1, {node} profile, {og_uid} ou1, {node} n1) \n";
  $query .= " LEFT JOIN {og_uid} ou2 ON (ou1.nid = ou2.nid) \n";
  $query .= implode("\n", $pfields['joins']) ." \n";
  $query .= " INNER JOIN {node} n2 ON (profile.uid = n2.uid AND n2.type = '%s') \n";
  $query .= " INNER JOIN ". $db_info['field_section_id']['table'] ." ON (". $db_info['field_section_id']['table'] .".nid  = n2.nid)\n";
  $query .= " INNER JOIN {node} n3 ON (n3.nid = ". $db_info['field_section_id']['columns']['nid']['column'] .") \n";
  $query .= " INNER JOIN ". $db_info['field_parent_section']['table'] ." ON (". $db_info['field_parent_section']['table'] .".nid  = n3.nid)\n";
  $query .= " INNER JOIN {node} n4 ON (n4.nid = ". $db_info['field_parent_section']['columns']['nid']['column'] .") \n";

  $query .= " WHERE ou1.is_admin <> %d \n";
  $query .= " AND ou1.is_active = %d \n";
  $query .= " AND n1.type = '%s' \n";
  $query .= " AND n1.nid = ou1.nid \n";
  
  $query .= " AND ou2.is_admin = %d \n";
  $query .= " AND ou2.uid <> n1.uid \n";
  $query .= " AND ou2.uid = u1.uid \n";
  
  $query .= " AND profile.type = '%s' \n";
  $query .= " AND profile.uid = ou2.uid \n";

  // secretaries and faculty officers can only see their course advisers
  if(($user->is_secretary) || ($user->is_faculty_officer)) {
    $filter_uids = " AND ou2.uid  IN (". implode(', ', $uids) .") \n";
    $query .= $filter_uids;
  }
  else {
    $filter_uids = '';
  }
  
  $group_by = " GROUP BY ou2.uid, ou1.nid \n";
  $query .= $group_by;
  
  $args = array();
  $args[] = 'profileedu'; 
  $args[] = 1;
  $args[] = 1;
  $args[] = variable_get('course_registration_group', 'pe_group_registration');
  $args[] = 1;
  $args[] = 'profile'; 
  
  $count_sql = '';
  $count_sql .= " SELECT COUNT(DISTINCT ou2.uid) \n";
  $count_sql .= " FROM ({users} u1, {node} profile, {og_uid} ou1, {node} n1) \n";
  $count_sql .= " LEFT JOIN {og_uid} ou2 ON (ou1.nid = ou2.nid) \n";
  $count_sql .= " WHERE ou1.is_admin <> %d \n";
  $count_sql .= " AND ou1.is_active = %d \n";
  $count_sql .= " AND n1.type = '%s' \n";
  $count_sql .= " AND n1.nid = ou1.nid \n";  
  $count_sql .= " AND ou2.is_admin = %d \n";
  $count_sql .= " AND ou2.uid <> n1.uid \n";
  $count_sql .= " AND ou2.uid = u1.uid \n";
  $count_sql .= $filter_uids;
  $count_sql .= $group_by;
  
  $header = array(
    array('data' => t('#')),
    array('data' => t('Name'), 'field' => 'field_lastname', 'sort' => 'asc'),
    array('data' => t('Gender'), 'field' => 'field_gender'),
    array('data' => t('Faculty'), 'field' => 'parent_section_title'),
    array('data' => t('Department'), 'field' => 'section_title'),
    array('data' => t('Groups'), 'field' => 'total_groups'),
    array('data' => t('Students'), 'field' => 'total_students'),
    array('data' => t('Operations')),
  );
  
  $show_count = variable_get('items_per_page', 100);
  $tablesort = tablesort_sql($header);  
  $result = pager_query($query . $tablesort, $show_count, 0, $count_sql, $args);
  
  $rows = array();
  $i = 0;
  while($row = db_fetch_object($result)) {
    // mock up user profile
    $account = new stdClass();
    $account->uid = $row->course_adviser_uid;
    $account->name = $row->name;
    $account->profile->field_lastname[0]['value'] = $row->field_lastname;
    $account->profile->field_firstname[0]['value'] = $row->field_firstname;
    $account->profile->field_personal_title[0]['value'] = _translate_personal_title($row->field_personal_title);
    
    $path = 'pe_course/registration/'. arg(2) .'/'. $row->course_adviser_uid;
    $attributes = array('title' => t('View groups'));
    
    $rows[] = array(
      array('data' => $i + 1, 'align' => 'center'),
      array('data' => theme('username', $account, $link = 1, $access = 1, $path, $attributes)),
      array('data' => ($row->field_gender != '') ? theme('image', drupal_get_path('theme', $conf['theme_default']) .'/images/icon_'. drupal_strtolower($row->field_gender) .'.gif')  : '--', 'align' => 'center'),
      array('data' => $row->parent_section_title),
      array('data' => $row->section_title),
      array('data' => $row->total_groups, 'align' => 'center'),
      array('data' => $row->total_students, 'align' => 'center'), 
      array('data' => l(t('Details'), $path, array('attributes' => $attributes)), 'align' => 'center'),   
    );
    $i++;
  }
  
  if (count($rows) < 1) {
    $rows[] = array(array('data' => t('No course advisers found.'), 'colspan' => count($header), 'align' => 'center'));
  }
  
  $pager = theme('pager', NULL, $show_count, 0);
  $output .= $pager;
  $output .= theme('table', $header, $rows);
  $output .= $pager;  
  
  return $output;
    
}


/**
 * Start page for course advisers
 *
 * @global <type> $user
 * @global <type> $conf
 * @param <type> $course_adviser
 * @return <type>
 */
function _adviser_registration_home($course_adviser) {
  global $user, $conf;
  
  $type = array('pe_group_registration');
  $gids = _get_og_nids($type, (array)$course_adviser, $manager = array()); // course reg group nids
  $uids = _get_og_uids($gids); // student uids

  $db_info['field_credits'] = _get_content_database_info('field_credits', 'pe_course');

  $profiles = array(
    'profile' => array('field_firstname','field_lastname', 'field_personal_title', 'field_gender'),
  );
  
  $profileedus = array(
    'profileedu' => array('field_studentid'),
  );
 
  $pfields = array();
  $pfields[] = _get_profile_fields_sql($profiles);
  $pfields[] = _get_profile_fields_sql($profileedus);
  
  $query = '';
  $query .= " SELECT profile.nid, u1.uid AS student_uid, u1.name, acad_program_table.title AS field_acad_program, \n";
  $query .= " t.name AS student_level, COUNT(DISTINCT pending.nid) AS total_pending, COUNT(DISTINCT accepted.nid) AS total_accepted, COUNT(DISTINCT declined.nid) AS total_declined, \n";
  for($i = 0; $i < count($pfields); $i++) {
    $query .= implode(', ', $pfields[$i]['selects']) ."";
    $query .= ($i < (count($pfields)-1)) ? ", " : "";
  }
  $query .= "\n";
  $query .= " FROM ({users} u1, {node} acad_program_table, {vocabulary} v) \n";
  $query .= " INNER JOIN {node} profile ON (profile.uid = u1.uid) \n";
  $query .= " INNER JOIN {node} profileedu ON (profileedu.uid = u1.uid) \n";
  $query .= " LEFT JOIN {pe_course_wishlist} pending ON (pending.uid = u1.uid AND pending.status = ". PENDING ." AND pending.ayid = %d) \n";
  $query .= " LEFT JOIN {pe_course_wishlist} accepted ON (accepted.uid = u1.uid AND accepted.status = ". ACCEPTED ." AND accepted.ayid = %d) \n";
  $query .= " LEFT JOIN {pe_course_wishlist} declined ON (declined.uid = u1.uid AND declined.status = ". DECLINED ." AND declined.ayid = %d) \n";
  for($j = 0; $j < count($pfields); $j++) {
    $query .= implode("\n", $pfields[$j]['joins']) ." \n";
  }
  $query .= " INNER JOIN {content_field_acad_program_id} ON (content_field_acad_program_id.nid = profileedu.nid AND content_field_acad_program_id.field_acad_program_id_nid = acad_program_table.nid) \n";
  $query .= " INNER JOIN {term_data} t ON (v.vid = t.vid) \n";
  $query .= " INNER JOIN {term_node} tn ON (profileedu.nid = tn.nid AND tn.tid = t.tid) \n";
  $query .= " WHERE profile.type = '%s' \n";
  $query .= " AND profileedu.type = '%s' \n";
  $query .= " AND v.name = '%s' \n";  
  $query .= " AND u1.uid  IN (". implode(', ', $uids) .") \n";
  $query .= " GROUP BY u1.uid \n";
  
  $args = array(
    $user->acad_year->nid,
    $user->acad_year->nid,
    $user->acad_year->nid,
    'profile',
    'profileedu',
    variable_get('student_level_vocab', t('Level'))
    );

  $count_sql = _get_og_uids($gids, $is_active = 1, $no_admin_manager = 1, $no_manager = 0, $no_admin = 0, $orderby='ou.uid ASC', TRUE, TRUE);

  $header = array(
    array('data' => t('#')),
    array('data' => t('Name'), 'field' => 'field_lastname', 'sort' => 'asc'),
    array('data' => t('Gender'), 'field' => 'field_gender'),
    array('data' => t('StudentID'), 'field' => 'field_studentid'),
    array('data' => t('Program'), 'field' => 'field_acad_program'),
    array('data' => t('Level'), 'field' => 'student_level'),
    array('data' => t('Operations')),
  );
  
  $show_count = variable_get('items_per_page', 100);
  $tablesort = tablesort_sql($header);  
  $result = pager_query($query . $tablesort, $show_count, 0, $count_sql, $args);

  $rows = array();
  $i = 0;
  while($row = db_fetch_object($result)) {
    $student = user_load($row->student_uid);    
    $path = 'pe_course/registration/'. arg(2) .'/'. arg(3) .'/'. $row->student_uid;
    $attributes = array('title' => t('View this student\'s courses'));
    
    $rows[] = array(
      array('data' => $i + 1, 'align' => 'center'),
      array('data' => theme('username', $student, $link = 1, $access = 1, $path, $attributes)),
      array('data' => ($row->field_gender != '') ? theme('image', drupal_get_path('theme', $conf['theme_default']) .'/images/icon_'. drupal_strtolower($row->field_gender) .'.gif')  : '--', 'align' => 'center'),
      array('data' => $row->field_studentid),
      array('data' => $row->field_acad_program),
      array('data' => $row->student_level),
      array('data' => (count($student->course_list))
      ? l(t('Courses list'), 'user/'. $student->uid, array('title' => t('List of courses for @ayear', array('@ayear' => $student->acad_year->title))))
      : t('P') .'('. l($row->total_pending, $path .'/'. PENDING, array('title' => t('Pending'))) .')/'.
      t('A') .'('. l($row->total_accepted, $path .'/'. ACCEPTED, array('title' => t('Accepted'))) .')/'.
      t('D') .'('. l($row->total_declined, $path .'/'. DECLINED, array('title' => t('Declined'))) .')', 'align' => 'center'
      ), 
    );
    $i++;
  }  
  if (count($rows) < 1) {
    $rows[] = array(array('data' => t('No students found.'), 'colspan' => count($header), 'align' => 'center'));
  }
  
  $output = '';
  $output .= theme('table', $header, $rows);
  $output .= theme('pager', NULL, $show_count, 0);  
  
  return $output;
}


/**
 * Start page for students
 *
 * @global <type> $user
 * @param <type> $student_uid
 * @param <type> $course_status
 * @return <type>
 */
function student_registration_home($student_uid, $course_status='') {
  global $user;
  
  $student = user_load($student_uid);
  
  $course_status = ($course_status == '') ? '-1' : $course_status;
  $courses = array(
    'fields' => array(
      'pe_course' => array('field_code', 'field_acad_term_id','field_credits', 'field_acad_year'),
    ),
  );
  
  $dfields = _build_cck_sql($courses);
 
  $query = '';
  $query .= " SELECT pe_course.nid, pe_course.title AS course_title, ";
  $query .= implode(", ", $dfields['selects']) ."";
  
  $query .= ", SUBSTRING(node_content_type_pe_course.title, -1) AS acad_term, td1.name AS course_weight, cw.locked, cw.status";
  $query .= "\n";
  $query .= " FROM (";
  $query .= implode(", ", $dfields['froms']) ."";
  $query .= ") \n";
  $query .= " LEFT JOIN {term_node} tn1 ON (tn1.nid = pe_course.nid) \n";
  $query .= " LEFT JOIN {vocabulary} v1 ON (tn1.vid = v1.vid AND v1.name = '%s') \n";
  $query .= " LEFT JOIN {term_data} td1 ON (td1.tid = tn1.tid) \n";
  $query .= " LEFT JOIN {pe_course_wishlist} cw ON (pe_course.nid = cw.nid AND cw.uid = %d) \n";
  $query .= implode("\n", $dfields['joins']) ."";
  $query .= "\n";
  $query .= " WHERE ";
  $query .= implode("\n AND ", $dfields['ands']) ."";
	$query .= " AND table_field_acad_year.field_acad_year_value = '%s'";

	$args = array();		  
  $args[] = variable_get('course_weight_vocab', t('Course weight'));
  $args[] = $student_uid;

	if(sizeof($dfields['args'])) {
		foreach($dfields['args'] as $id => $arg) {
			$args[] = $arg;
		}
  }

  $args[] = $user->acad_year->title;

  if($course_status >= 0) {
		$query .= " AND cw.status = %d\n";
    $args[] = $course_status;
  }

  $count_sql = '';
  $count_sql .= " SELECT COUNT(pe_course.nid) ";
  $count_sql .= "\n";
  $count_sql .= " FROM (";
  $count_sql .= implode(", ", $dfields['froms']) ."";
  $count_sql .= ") \n";
  $count_sql .= implode("\n", $dfields['joins']) ."";
  $count_sql .= " LEFT JOIN {pe_course_wishlist} cw ON (pe_course.nid = cw.nid AND cw.uid = ". $student_uid .") \n";
  $count_sql .= "\n";
  $count_sql .= " WHERE ";
  $count_sql .= implode("\n AND ", $dfields['ands']) ."";
  $count_sql .= " AND table_field_acad_year.field_acad_year_value = '".$user->acad_year->title."'";
  if($course_status >= 0) {
    $count_sql .= " AND cw.status = ". $course_status ."\n";
  }
	$show_count = variable_get('items_per_page', 100);

	$result = pager_query($query . $tablesort, $show_count, 0, $count_sql, $args);
  
  $destination = drupal_get_destination();

	$wished = 0;
	$nodes = array();
  $total_credits = 0;
  while ($node = db_fetch_object($result)) {
		$nodes[$node->nid] = '';
    $form['title'][$node->nid] = array('#value' => l($node->course_title, 'node/'. $node->nid));    
    $form['code'][$node->nid] =  array('#value' => $node->field_code);
    $form['acad_term'][$node->nid] = array('#value' => $node->acad_term);
    $form['credits'][$node->nid] =  array('#value' => $node->field_credits);
    $form['course_weight'][$node->nid] = array('#value' => $node->course_weight);
    $form[$node->nid]['course_status['.$node->nid.']'] = (($user->is_student) || ($node->locked))  ? array('#value' => _get_course_status($node->status)) : array('#type' => 'select', '#default_value' => $node->status, '#options' => _course_status_options());
    $total_credits += ($node->status == ACCEPTED) ? $node->field_credits : 0;
		if($node->status >= 0) {
			$wished = 1;
		}
  }
  
  $vocabs = taxonomy_get_vocabularies('profileedu');
  foreach($vocabs as $key => $vocab) {
    $vid = ($vocab->name == variable_get('student_level_vocab', 'Level')) ? $key : 0;
  }

	if(sizeof($student->profileedu->taxonomy)) {
		foreach($student->profileedu->taxonomy as $key => $term) {
			$tid = ($vid == $term->vid) ? $key : 0;
		}
	} else {
		$tid = 0;
	}
  
  // credits
  $credits = _get_min_max_credits($student->profileedu->field_acad_program_id[0]['nid'], $tid);

  $min_max_credits = '';
  if($credits['min'] > 0) {
    $min_max_credits .= $credits['min'];
  }
  
  if($credits['max'] > 0) {
    $min_max_credits .= '/'. $credits['max'];
  }
  
  $_SESSION[$student->uid]['total_credits'] = $total_credits;
  $_SESSION[$student->uid]['acad_year_nid'] = $student->acad_year->nid;
  $_SESSION[$student->uid]['acad_year_title'] = $student->acad_year->title;
  $_SESSION[$student->uid]['min_max_credits'] = $min_max_credits;
  $_SESSION[$student->uid]['is_registered'] = (count($student->course_list) > 0) ? 1 : 0;
  
	$form['wished'] = array('#type' => 'value', '#value' => $wished);
  $form['student_uid'] = array('#type' => 'value', '#value' => $student->uid);
  $form['nodes'] = array('#type' => 'checkboxes', '#options' => $nodes, '#disabled' => $_SESSION[$student->uid]['is_registered']);
  $form['pager'] = array('#value' => theme('pager', NULL, $show_count, 0));
  $form['#theme'] = 'student_registration_home';
  
  return $form;  
  
}


/**
 * Select a faculty officer from a dropdown select box
 *
 * @param <type> $form_state
 * @param <type> $facors_group_admin
 * @return <type>
 */
function officer_select_options_form(&$form_state, $facors_group_admin) {
  
  $form['filter'] = array(
    '#type' => 'fieldset',
    '#title'  => t('Faculty officer'),
    '#description'  => "<p>". t('Select a faculty officer from the list.') ."</p>",
    '#collapsed'  => FALSE,
    '#collapsible'  => TRUE,
  );
  
  $form['filter']['officer_uid'] = array(
    '#type' => 'select',
    '#default_value' => arg(2),
    '#title' => '',
    '#options' => _faculty_officer_options($facors_group_admin),
    '#prefix' => '<div class="container-inline">',
  );

  $form['filter']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Filter'),
    '#suffix' => '</div>',
  );
  $form['#submit'] = array('officer_select_options_form_submit');
  
  return $form;
}

/**
 * Select a course adviser from a dropdown select box
 *
 * @param <type> $form_state
 * @param <type> $default_officer_uid
 * @return <type>
 */
function adviser_select_options_form(&$form_state, $default_officer_uid) {
	$form['filter'] = array(
    '#type' => 'fieldset',
    '#title'  => t('Course adviser'),
    '#description'  => "<p>". t('Select a course adviser from the list.') ."</p>",
    '#collapsed'  => FALSE,
    '#collapsible'  => TRUE,
  );

  $form['filter']['adviser_uid'] = array(
    '#type' => 'select',
    '#default_value' => arg(3),
    '#title' => '',
    '#options' => _course_adviser_options($default_officer_uid),
    '#prefix' => '<div class="container-inline">',
    );
   
	$form['filter']['officer_uid'] = array(
    '#type' => 'hidden',
    '#value' => $default_officer_uid,
  );
  
  $form['filter']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Filter'),
    '#suffix' => '</div>',
    );
  $form['#submit'] = array('adviser_select_options_form_submit');
  return $form;
}


/**
 * Select a student from a dropdown select box
 *
 * @global <type> $user
 * @param <type> $default_officer_uid
 * @return <type>
 */
function student_select_options_form($default_officer_uid) {
  global $user;

	if (!$user->is_student) {
		$default_adviser_uid = arg(3);

		$form['students-filter'] = array(
			'#type' => 'fieldset',
			'#title'  => t('Course advisers/Students'),
			'#description'  => "<p>". t('Select a student for the active course adviser from the list.') ."</p>",
			'#collapsed'  => FALSE,
			'#collapsible'  => FALSE,
			'#prefix' => '<div class="container-inline">',
		);

	 $form['officer_uid'] = array(
			'#type' => 'value',
			'#value' => $default_officer_uid,
		);

		$form['adviser_uid'] = array(
			'#type' => 'value',
			'#value' => $default_adviser_uid,
		);

		$form['students-filter']['student_uid'] = array(
			'#type' => 'select',
			'#default_value' => arg(4),
			'#title' => '',
			'#options' => _student_options($default_adviser_uid),
			);
		$form['students-filter']['status'] = array(
			'#type' => 'select',
			'#default_value' => arg(5),
			'#title' => '',
			'#options' => _course_status_options(),
			);

		$form['students-filter']['submit'] = array(
			'#type' => 'submit',
			'#value' => t('Filter'),
			'#submit' => array('students_filter_form_submit'),
			'#suffix' => '</div>',
			);
	}

  $form['action'] = array(
    '#type' => 'fieldset',
    '#title'  => t('Operation'),
    '#collapsed'  => FALSE,
    '#collapsible'  => FALSE,
    '#prefix' => '<div class="container-inline">',
  );
  
  // operations
	$op = array('0' => t('<none>'));
  if (($user->uid == 1) || ($user->is_course_adviser)  || ($user->is_faculty_officer)) {

		$op = array_merge($op, array('status' => t('Change status')));

		if (($user->uid == 1) || ($user->is_faculty_officer)) {
			$op = array_merge($op, array('lock' => t('Lock courses'), 'unlock' => t('Unlock courses'), 'confirm' => t('Confirm courses')));
		}
	}
	
  if(($user->uid == 1) || ($user->is_student)) {
		$op = array_merge($op, array('add' => t('Add to Wishlist'), 'delete' => t('Delete from Wishlist')));
	}
  
  $form['action']['operation'] = array(
    '#type' => 'select',
    '#default_value' => $_SESSION['op'],
    '#title' => '',
    '#options' => $op,
    );
  
  $form['action']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Operation'),
    '#submit' => array('pe_course_registration_operations_form_submit'),
    '#suffix' => '</div>',
    );    
    
  $form['#theme'] = 'student_select_options_form';
  
  return $form;
}

/**
 * Theme student registration home overview.
 *
 * @ingroup themeable
 */
function theme_student_registration_home($form) {
	global $user;
	
  $student_uid = $form['student_uid']['#value'];
  // If there are rows in this form, then $form['title'] contains a list of
  // the title form elements.
  $has_courses = isset($form['title']) && is_array($form['title']);
  $select_header = (($has_courses) && (!$_SESSION[$student_uid]['is_registered']) && ($form['wished']['#value'] != 1)) ? theme('table_select_header_cell') : '';
  
	$header = array(
  	$select_header, 
  	array('data' => t('Title'), 'field' => 'course_title'), 
  	array('data' => t('Code'), 'field' => 'field_code'), 
  	array('data' => t('Term'), 'field' => 'acad_term'), 
  	array('data' => t('Credits'), 'field' => 'field_credits'), 
  	array('data' => t('Weight'), 'field' => 'course_weight'), 
  	t('Status'),
  	);

	$status_options = _course_status_options();
	array_shift($status_options);

  $total_credits = 0;
  if ($has_courses) {
    foreach (element_children($form['title']) as $key) {
      $row = array();
			
			if(($user->is_student) && (in_array($form[$key]['course_status['.$key.']']['#value'], $status_options))) {
				$form['nodes'][$key]['#attributes']['disabled'] = 'disabled';
			}
			
      $row[] = drupal_render($form['nodes'][$key]);
      $row[] = drupal_render($form['title'][$key]);
      $row[] = drupal_render($form['code'][$key]);
      $row[] = drupal_render($form['acad_term'][$key]);
      $row[] = drupal_render($form['credits'][$key]);
      $row[] = drupal_render($form['course_weight'][$key]);

      if($_SESSION[$student_uid]['is_registered']) {
        if(drupal_strlen($form[$key]['course_status['.$key.']']['#value']) > 0) {
          $row[] = drupal_render($form[$key]['course_status['.$key.']']);
        }
        else {
          $row[] = t('--');
					unset($form[$key]['course_status['.$key.']']);
        }
      }
      else {
				$row[] = drupal_render($form[$key]['course_status['.$key.']']);
      }			
      $rows[] = $row;
    }    
  }
  else {
    $rows[] = array(array('data' => t('No courses found.'), 'colspan' => count($header), 'align' => 'center'));
  }
  
  $output = ''; 
  $output .= '<p>'. t('Total credits: %total of %max', array('%total' => $_SESSION[$student_uid]['total_credits'], '%max' => $_SESSION[$student_uid]['min_max_credits'])) .'</p>';
  $output .= theme('table', $header, $rows);
  if ($form['pager']['#value']) {
    $output .= drupal_render($form['pager']);
  }

  $output .= drupal_render($form);

  return $output;
}


/**
 * Submit faculty officer select option
 *
 * @param <type> $form
 * @param <type> $form_state
 */
function officer_select_options_form_submit($form, &$form_state) {
	$_SESSION['officer_uid'] = $form_state['values']['officer_uid'];
  drupal_goto('pe_course/registration/'. $_SESSION['officer_uid']);
}

/**
 * Submit adviser select option
 *
 * @param <type> $form
 * @param <type> $form_state
 */
function adviser_select_options_form_submit($form, &$form_state) {
  $_SESSION['officer_uid'] = $form_state['values']['officer_uid'];
  $_SESSION['adviser_uid'] = $form_state['values']['adviser_uid'];
  drupal_goto('pe_course/registration/'. $_SESSION['officer_uid'] .'/'. $_SESSION['adviser_uid']);
}


/**
 * Submit student select option
 *
 * @param <type> $form
 * @param <type> $form_state
 */
function student_select_options_form_submit($form, &$form_state) {
  $adviser_uid = $form_state['values']['adviser_uid'];
  $student_uid = $form_state['values']['student_uid'];
  drupal_goto('pe_course/registration/'. arg(2) .'/'. $adviser_uid .'/'. $student_uid);
}


/**
 * Submit student filter select option
 *
 * @param <type> $form
 * @param <type> $form_state
 */
function students_filter_form_submit($form, &$form_state) {
	if($form_state['values']['op'] == t('Filter')) {
    if( (is_numeric($form_state['values']['officer_uid'])) && (is_numeric($form_state['values']['adviser_uid'])) && (is_numeric($form_state['values']['student_uid'])) ) {
      $_SESSION['officer_uid'] = $form_state['values']['officer_uid'];
      $_SESSION['adviser_uid'] = $form_state['values']['adviser_uid'];
      $_SESSION['student_uid'] = $form_state['values']['student_uid'];
			$_SESSION['status'] = $form_state['values']['status'];
    
      $allowed_statuses = array(PENDING, ACCEPTED, DECLINED);
      $tail = (in_array($form_state['values']['status'], $allowed_statuses)) ? '/'. $form_state['values']['status'] : '';
      drupal_goto('pe_course/registration/'. arg(2) .'/'. $form_state['values']['adviser_uid'] .'/'. $form_state['values']['student_uid'] . $tail);
      
    }
    else {
      drupal_set_message(t('Incomplete criteria for finding a student.'), 'error');
      drupal_goto('pe_course/registration');
    }
	}
}

/**
 * Submit course registration operation form
 *
 * @global <type> $user
 * @param <type> $form
 * @param <type> $form_state
 */
function pe_course_registration_operations_form_submit($form, &$form_state) {
	global $user;

	$error = 0;
  if($form_state['values']['op'] == t('Operation')) {
    $allowed_operations = array('status', 'lock', 'unlock', 'add', 'delete', 'confirm');
    if (!in_array($form_state['values']['operation'], $allowed_operations)) {
      $error = 1;
      $message = t('No valid operation selected.');
    }

    if(($user->uid > 1) && (!$user->is_faculty_officer) && (!$user->is_course_adviser) && (!$user->is_secretary) && (!$user->is_student)) {
      $error = 1;
      $message = t('You do not have permission to carry put this operation.');
    }

		$nodes = array_filter($form_state['values']['nodes']);
    $total_courses = count($nodes);

		if($total_courses < 1) {
			$error = 1;
			$message =t('You have not selected any courses to process.');
		}

		if(!$error) {
      $total_credits = $_SESSION[$form_state['values']['student_uid']]['total_credits'];
      $min_max_credits = $_SESSION[$form_state['values']['student_uid']]['min_max_credits'];
      $acad_year_nid = $_SESSION[$form_state['values']['student_uid']]['acad_year_nid'];
      $acad_year_title = $_SESSION[$form_state['values']['student_uid']]['acad_year_title'];

			if(($user->uid == 1) || ($user->is_student)) {
        foreach($nodes as $node => $nid) {
					if($form_state['values']['operation'] == 'add') {
						db_query("INSERT INTO {pe_course_wishlist} (uid, nid, ayid, status, locked, created, updated, confirmed) VALUES(%d, %d, %d, %d, %d, %d, %d, %d)", $form_state['values']['student_uid'], $nid, $acad_year_nid, $form_state['clicked_button']['#post']['course_status'][$nid], 0, time(), 0, 0);
					}
					elseif($form_state['values']['operation'] == 'delete') {
						db_query("DELETE FROM {pe_course_wishlist} WHERE uid = %d AND ayid = %d AND status = %d", $form_state['values']['student_uid'], $acad_year_nid, PENDING);
					}
        }
			}

      if (!$user->is_student) {
        // update course status
        if($form_state['values']['operation'] == 'status') {
          foreach($nodes as $node => $nid) {
            // old
            $result = db_query("UPDATE {pe_course_wishlist} SET status = %d, updated = %d WHERE uid = %d AND nid = %d AND ayid = %d", $form_state['clicked_button']['#post']['course_status'][$nid], time(), $form_state['values']['student_uid'], $nid,	$acad_year_nid);
            // new
            if((db_affected_rows($result) == 0) && ($form_state['clicked_button']['#post']['course_status'][$nid] >= PENDING)) {
              db_query("INSERT INTO {pe_course_wishlist} (uid, nid, ayid, status, locked, created, updated, confirmed) VALUES(%d, %d, %d, %d, %d, %d, %d, %d)", $form_state['values']['student_uid'], $nid, $acad_year_nid, $form_state['clicked_button']['#post']['course_status'][$nid], 0, time(), 0, 0);
            }
          }
        }
        
        if(($user->uid == 1) || ($user->is_faculty_officer)) {
          // lock/unlock courses
          if(($form_state['values']['operation'] == 'lock') || ($form_state['values']['operation'] == 'unlock')) {
            $lock = ($form_state['values']['operation'] == 'lock') ? 1 : 0;
            foreach($nodes as $node => $nid) {
              db_query("UPDATE {pe_course_wishlist} SET locked = %d, confirmed = %d WHERE uid = %d AND ayid = %d", $lock, time(), $form_state['values']['student_uid'], $acad_year_nid);
            }
          }
          // confirm courses
          if($form_state['values']['operation'] == 'confirm') {
            $credits = explode('/', $min_max_credits);
            if($total_credits < $credits[0]) {
              $error = 1;
              $message = t('Too low total credits');
            }
            elseif(($credits[1] > 0) && ($total_credits > $credits[1])) {
              $error = 1;
              $message = t('Too high total credits');
            }
            else {
              $nids = array();
              // pe_course_wishlist - update
              foreach($form_state['clicked_button']['#post']['course_status'] AS $nid => $status) {
                db_query("UPDATE {pe_course_wishlist} SET locked = %d, confirmed = %d WHERE uid = %d AND nid = %d AND ayid = %d", 1, time(), $form_state['values']['student_uid'], $nid, $acad_year_nid);
                // pe_course_list - insert
                if($status == ACCEPTED) {
                  db_query("INSERT INTO {pe_course_list} (uid, nid, ayid) VALUES (%d, %d, %d)", $form_state['values']['student_uid'], $nid, $acad_year_nid);
                  $nids[] = $nid;
                }
              }
            }
          }
        }
      }

      // there can be an error at the confirmation stage
      if(!$error) {
        if(count($nids) > 0) {
          $success = _send_registration_notification($student_uid, $nids);
          $note = ($success) ? t('and email notifications have been sent out.') : t('but email notifications could not be sent.');
          $message = t('The student has been registered for %confirmed courses and %total credits for the %title academic year %note', array('%confirmed' => $confirmed, '%total' => $total_credits, '%title' => $acad_year_title, '%note' => $note));
        }
        else {
          $message = format_plural(count($nodes), 'You have updated <strong>1</strong> course.', 'You have updated <strong>@count</strong> courses.');
        }
      }
		}
	}
  $type = ($error) ? 'error' : 'status';
  drupal_set_message($message, $type);
}


/**
 * Send email notifications to the student, course adviser and faculty officer about the
 * successfull course registration for the academic year
 * 
 * @global <type> $user
 * @param <type> $uid
 * @param <type> $nids
 */
function _send_registration_notification($uid, $nids) {
  global $user;
  
  $student = user_load(array('uid' => $uid));

  $i = 0;
  $result = db_query('SELECT title FROM {node} WHERE nid IN(%s)', implode(',', $nids));
  while ($node = db_fetch_object($result)) {
    $courses[] = $i + 1 .'. '. $node->title;
  }
  $course_titles = implode('\r\n', $courses);

  $site_name = variable_get('site_name', 'phpEdu LMS');
  $from = "$site_name <" . variable_get('site_mail', ini_get('sendmail_from')) . '>';
  $subject = str_replace(array("\r", "\n"), '', variable_get('course_regn_message_subject', 'Course Registration'));

  $email_student = $student->email;
  $email_faculty_officer = ($user->is_faculty_officer) ? $user->email : _get_user_email(arg(2));
  $email_course_adviser = _get_user_email(arg(3));

  $variables = array(
    '%lastname' => $student->profile->field_lastname[0]['value'],
    '%firsname' => $student->field_firstname[0]['value'],
    '%acad_year' => $student->acad_year->title,
    '%courses_list' => $courses_list,
    '%matric' => $student->field_studentid[0]['value'],
    '%program' => $student->profileedu->acad_program,
    '%study_level' => $student->profileedu->student_level,
  );

  $course_regn_message_student = variable_get('course_regn_message_student', 'Dear %lastname %firstname,\r\n\r\nThese are the courses you have been registered for this academic year, %acad_year.\r\n%courses_list\r\nIf you have any questions please contact your Course Adviser.');
  $course_regn_message_staff = variable_get('course_regn_message_staff', '%lastname, %firstname (%matric)\r\n%program, Level %study_level\r\n-------------------------------------------------------------------------\r\n\r\nThese are the courses the above-named student has been registered for, this academic year, %acad_year.\r\n\r\n%courses_list.');
  
  $msg_student = strtr($course_regn_message_student, $variables);
  $msg_staff = strtr($course_regn_message_staff, $variables);

  $student_mail_success = drupal_mail('courses_notify_student', $email_student, $subject, $msg_student, "From: $from\nReply-to: $from\nX-Mailer: Drupal\nReturn-path: $from\nErrors-to: $from" );
  
  if ($student_mail_success) {
    watchdog('courses', t('Sent email to %email_student', array('%email_student' => $email_student)));
  }
  else {
    watchdog('error', t('Unable to send email to %email_student', array('%email_student' => $email_student)));
  }

  $staff_mail_success =drupal_mail('courses_notify_staff', $email_faculty_officer, $subject, $msg_staff, "From: $from\nReply-to: $from\nX-Mailer: Drupal\nReturn-path: $from\nErrors-to: $from", $headers = array('Cc' => $email_course_adviser) );
  
  if ($staff_mail_success) {
    watchdog('courses', t('Sent email to %email_faculty_officer', array('%email_faculty_officer' => $email_faculty_officer)));
  }
  else {
    watchdog('error', t('Unable to send email to %email_faculty_officer', array('%email_faculty_officer' => $email_faculty_officer)));
  }
  
  $success = ($student_mail_success && $staff_mail_success) ? true : false;

  return $success;
  
}


/**
 * Start page for faculty officers
 *
 * @global <type> $user
 * @return <type>
 */
function pe_course_officer_home() {
  global $user;

  if(($user->uid == 1) || ($user->is_secretary) || ($user->is_faculty_officer)) {
    $faculty_officer = arg(2);

    $output = '';
    if(($user->uid == 1) || ($user->is_secretary)) {
      // facor groups are managed by secretaries
      $facors_group_admin = ($user->is_secretary) ? $user->is_secretary : '';
      $output .= drupal_get_form('officer_select_options_form', $facors_group_admin);
    }
    
    $output .= _officer_registration_home($faculty_officer);
    
    return $output;
  }
  else {
    drupal_goto('pe_programs');
  }
}


/**
 * Start page for course advisers
 *
 * @global <type> $user
 * @return <type>
 */
function pe_course_adviser_home() {
	global $user;
  
  if(($user->uid == 1) || ($user->is_secretary) || ($user->is_faculty_officer) || ($user->is_course_adviser)) {
    $faculty_officer = arg(2);
    $course_adviser = arg(3);
		
    $output = '';
    if(!$user->is_course_adviser) {
      $output .= drupal_get_form('adviser_select_options_form', $faculty_officer);
    }    
    
    $output .= _adviser_registration_home($course_adviser);
    return $output;
  }
  else {
    drupal_goto('pe_programs');
  }
}


/**
 * Start page for students
 *
 * @global <type> $user
 * @param <type> $form_state
 * @return <type>
 */
function pe_course_student_home($form_state) {
	global $user;

  if(($user->uid == 1) || ($user->is_secretary) || ($user->is_faculty_officer) || ($user->is_course_adviser) || ($user->is_student)) {
    $officeruid = arg(2);
    $course_adviser = arg(3);
    $student_uid = arg(4);
		$course_status = arg(5);
		
    //if (!$user->is_student) {
		$form = student_select_options_form($officeruid);
		$form['#theme'] = 'student_select_options_form';
    //}
    
    $form['courses'] = student_registration_home($student_uid, $course_status);
    
    return $form;
  }
  else {
    drupal_goto('pe_programs');
  }
}


/**
 * List of courses for teachers & students
 *
 * @global <type> $user
 * @param <type> $account
 */
function pe_course_list($account) {
  global $user;

  if(($user->uid == 1) || ($account->is_student) || ($account->is_teacher)) {
     
  }
  else {
    drupal_set_message(t('List of all courses are here.'));
    drupal_goto('pe_programs/courses');
  }
}


/**
 * Theme student select dropdown box
 *
 * @param <type> $form
 * @return <type>
 */
function theme_student_select_options_form($form) {
  $output = '';
  $output .= drupal_render($form);
  return $output;
}


/**
 * Get faculty officers for the select options dropdown box
 *
 * @global <type> $user
 * @param <type> $facors_group_admin
 * @return <type>
 */
function _faculty_officer_options($facors_group_admin) {
  global $user;
  
  $admin = array();
  $manager = ($facors_group_admin > 0) ? (array)$facors_group_admin : array();
  
  $officer_group_name = variable_get('officer_group_name', t('Faculty officers'));
  $officer_group_type = variable_get('officer_group_type', NODE_TYPE_GROUP);
  
  $gid = _get_og_by_name($officer_group_name, $officer_group_type, $admin, $manager);
  $uids = _get_og_uids(array($gid));

  $officers = array();
  if(count($uids) > 0) {
    foreach($uids as $uid) {
      $profile = user_load($uid);
      $officers[$uid] = theme('username', $profile, $link = 0, $access = 1, $path = '', $attributes = NULL);
    }
  }
  
  return $officers;
}


/**
 * Get course advisers in a course advice group managed by a faculty officer depending
 * on the user status for the select options dropdown box:
 *
 * su - <all course advisers> all cader groups
 * secretary - <my course advisers> Course adviser groups administered by my faculty officers
 *  - secretaries manage faculty officers > faculty officers manage course advice groups
 * faculty officer - <my course advisers>  course adviser groups they administer
 *
 * @global <type> $user
 * @param <type> $default_officer_uid
 * @return <type>
 */
function _course_adviser_options($default_officer_uid) {
  global $user;

  if($user->is_secretary) {
    // secs manage facors > facors administer course advice groups
    $officer_group_name = variable_get('officer_group_name', t('Faculty officers'));
    $officer_group_type = variable_get('officer_group_type', NODE_TYPE_GROUP);
    
    $oficer_gids = _get_og_by_name($officer_group_name, $officer_group_type, $admin, $manager);
    $admin = _get_og_uids(array($oficer_gids));
   
  }
  elseif ($user->is_faculty_officer) {
    $admin = array($user->uid);
  }
  else {
    $admin = array();
  }
  $manager = array();
  $adviser_group_type = variable_get('course_advisers_group', 'pe_group_advisers');
  $gids = _get_og_nids((array)$adviser_group_type, $admin, $manager);
  $uids = _get_og_uids($gids);

  $advisers = array();
  if(count($uids) > 0) {
    foreach($uids as $uid) {
      $profile = user_load($uid);
      $advisers[$uid] = theme('username', $profile, $link = 0, $access = 1, $path = '', $attributes = NULL);
    }
  }
  
  return $advisers;
}


/**
 * Get students in a registration group for the select options dropdown box
 *
 * @param <type> $adviser_uid
 * @return <type>
 */
function _student_options($adviser_uid) {
  $reg_group_type = variable_get('course_registration_group', 'pe_group_registration');
  $gids = _get_og_nids(array($reg_group_type), (array)$adviser_uid);
  $uids = _get_og_uids($gids);
  
  $students = array();
  if(count($uids) > 0) {
    foreach($uids as $uid) {
      $profile = user_load($uid);
      $students[$uid] = theme('username', $profile, $link = 0, $access = 1, $path = '', $attributes = NULL);
    }
  }
  return $students;
}

/**
 * Course status options array maps constants to strings
 *
 * @return array
 */
function _course_status_options() {
	return array ( 
		-1	=> '<'. t('N/A') .'>',
		PENDING => t('Pending'),
		ACCEPTED => t('Accepted'),
		DECLINED => t('Declined'),	
	);		
}

/**
 * Translate course status
 *
 * @param <type> $skey
 * @return <type>
 */
function _get_course_status($skey) {	
	$skey = (drupal_strlen($skey) > 0) ? $skey : -1;	
	$status = '';
	if($skey == -1) {
		$status .= t('N/A');
	} else {
		$options = _course_status_options();
		foreach($options as $key => $value) {
			if($skey == $key) {
				$status .= $value;
			}
		}
	}
	return $status;	
}
