<?php
// $Id:

/**
 * Sets the body-tag class attribute.
 *
 * Adds 'sidebar-left', 'sidebar-right' or 'sidebars' classes as needed.
 */
function phptemplate_body_class($left, $right) {
  if ($left != '' && $right != '') {
    $class = 'sidebars';
  }
  else {
    if ($left != '') {
      $class = 'sidebar-left';
    }
    if ($right != '') {
      $class = 'sidebar-right';
    }
  }

  if (isset($class)) {
    print ' class="'. $class .'"';
  }
}

/**
 * Return a themed breadcrumb trail.
 *
 * @param $breadcrumb
 *   An array containing the breadcrumb links.
 * @return a string containing the breadcrumb output.
 */
function phptemplate_breadcrumb($breadcrumb) {
  if((arg(0) == 'pe_programs') && (is_numeric(arg(2)))) {
    $trail = _get_title_from_nid(arg(2));
  }

  if(drupal_strlen($trail) > 0) {
    $breadcrumb[] = $trail;
  }

  if (!empty($breadcrumb)) {
    return '<div class="breadcrumb">'. implode(' › ', $breadcrumb) .'</div>';
  }
}

/**
 * Allow themable wrapping of all comments.
 */
function phptemplate_comment_wrapper($content, $node) {
  if (!$content || $node->type == 'forum') {
    return '<div id="comments">'. $content .'</div>';
  }
  else {
    return '<div id="comments"><h2 class="comments">'. t('Comments') .'</h2>'. $content .'</div>';
  }
}

/**
 * Override or insert PHPTemplate variables into the templates.
 */
function phptemplate_preprocess_page(&$vars) {
  $vars['tabs2'] = menu_secondary_local_tasks();

  // Hook into color.module
  if (module_exists('color')) {
    _color_page_alter($vars);
  }

  foreach($vars['template_files'] as $key => $tpl) {
    if((strpos($tpl, 'page-pe_programs-courses') !== FALSE) && is_numeric(arg(2)) ) {
        $title = _get_title_from_nid(arg(2));
        $head_title = explode('|', $vars['head_title']);

        $vars['title'] = $title;
        $vars['head_title'] = $title .' | '. $head_title[1];
    }
  }
}

/**
 * Returns the rendered local tasks. The default implementation renders
 * them as tabs. Overridden to split the secondary tasks.
 *
 * @ingroup themeable
 */
function phptemplate_menu_local_tasks() {
  return menu_primary_local_tasks();
}

function phptemplate_comment_submitted($comment) {
  return t('!datetime — !username',
    array(
      '!username' => theme('username', $comment),
      '!datetime' => format_date($comment->timestamp)
    ));
}

function phptemplate_node_submitted($node) {
  return t('!datetime — !username',
    array(
      '!username' => theme('username', $node),
      '!datetime' => format_date($node->created),
    ));
}

/**
 * Generates IE CSS links for LTR and RTL languages.
 */
function phptemplate_get_ie_styles() {
  global $language;

  $iecss = '<link type="text/css" rel="stylesheet" media="all" href="'. base_path() . path_to_theme() .'/fix-ie.css" />';
  if (defined('LANGUAGE_RTL') && $language->direction == LANGUAGE_RTL) {
    $iecss .= '<style type="text/css" media="all">@import "'. base_path() . path_to_theme() .'/fix-ie-rtl.css";</style>';
  }

  return $iecss;
}

/**
 * Theme the new-role form.
 *
 * @ingroup themeable
 */

function phptemplate_user_admin_new_role($form) {
  $header = array(t('Name'), array('data' => t('Operations'), 'colspan' => 2));
  foreach (user_roles() as $rid => $name) {
    $edit_permissions = l(t('edit permissions'), 'admin/user/permissions/'. $rid);
    if (!in_array($rid, array(DRUPAL_ANONYMOUS_RID, DRUPAL_AUTHENTICATED_RID, PHPEDU_TEACHER_RID, PHPEDU_STUDENT_RID, PHPEDU_STAFF_RID, PHPEDU_ALUMNUS_RID, PHPEDU_ADMINISTRATOR_RID, PHPEDU_SECRETARY_RID))) {
      $rows[] = array($name, l(t('edit role'), 'admin/user/roles/edit/'. $rid), $edit_permissions);
    }
    else {
      $rows[] = array($name, t('locked'), $edit_permissions);
    }
  }
  $rows[] = array(drupal_render($form['name']), array('data' => drupal_render($form['submit']), 'colspan' => 2));

  $output = drupal_render($form);
  $output .= theme('table', $header, $rows);

  return $output;
}


/**
 * Theme usernames. Get the user's title, first and last names from the
 * personal profile. If there's no personal profile or there's no access to
 * personal info, then display the username.
 *
 * @global object $user
 * @param object $object
 * @param boolean $link
 * @param boolean $access
 * @param string $path
 * @param <array $attributes
 * @return string $output
 *
 */
function phptemplate_username($object, $link = 1, $access = 0, $path = '', $attributes = NULL, $ptitle = 1) {
	global $user;

	$status = (($user->uid == 1) || ($user->is_teacher) || ($user->is_secretary)) ? TRUE : FALSE;

  if ($object->uid && $object->name) {
    // Shorten the name when it is too long or it will break many tables.
    if (drupal_strlen($object->name) > 20) {
      $name = drupal_substr($object->name, 0, 15) .'...';
    }
    else {
      $name = $object->name;
    }

    $username = ($status) ? ' ('. $name .')' : '';

		$lastname = $firstname = $fullname = '';
    if(is_object($object->profile)) {
    	$firstname .= eregi_replace(',', '', trim($object->profile->field_firstname[0]['value']));
      $lastname .= eregi_replace(',', '', trim($object->profile->field_lastname[0]['value']));
      if($ptitle) {
        $fullname .= (drupal_strlen($object->profile->field_personal_title[0]['value']) > 1) ? $object->profile->field_personal_title[0]['value'] .' ' : '';
      }
    }

    $fullname .= (($lastname != '') && ($firstname != '')) ? drupal_strtoupper($lastname) . ', ' . drupal_ucfirst(drupal_strtolower($firstname)) : $object->name;

		$show_link = (($access == 1) || (user_access('access user profiles'))) ? 1 : 0;

    if (($link) && ($show_link)) {
    	$path = (drupal_strlen($path) > 0) ? $path : 'user/'. $object->uid;
    	$attributes = (count($attributes) > 0) ? $attributes : array('title' => t('View user profile.'));
      $output = l($fullname, $path, array('attributes' => $attributes));
    }
    else {
      $output = check_plain($fullname);
    }
    $output .= ($fullname != $object->name) ? $username : '';
  }
  else if ($object->name) {
    // Sometimes modules display content composed by people who are
    // not registered members of the site (e.g. mailing list or news
    // aggregator modules). This clause enables modules to display
    // the true author of the content.
    if (!empty($object->homepage)) {
      $output = l($object->name, $object->homepage, array('attributes' => array('rel' => 'nofollow')));
    }
    else {
      $output = check_plain($object->name);
    }

    $output .= ' ('. t('not verified') .')';
  }
  else {
    $output = variable_get('anonymous', t('Anonymous'));
  }

  return $output;
}

/**
 *
 * @global <type> $conf
 * @param <type> $element
 * @return <type>
 */
function phptemplate_text_formatter_default($element) {
	global $conf;

	if($element['#field_name'] == 'field_lastname') {
  	return drupal_strtoupper($element['#item']['safe']);
  }
  elseif($element['#field_name'] == 'field_gender') {
  	return theme('image', drupal_get_path('theme', $conf['theme_default']) .'/images/icon_'. $element['#item']['safe'] .'.gif');
  }
  else {
  	return ($allowed =_text_allowed_values($element)) ? $allowed : $element['#item']['safe'];
  }
}


/**
 * Theme a form select element or output as default
 *
 * @param array $element
 * @return
 * Themed output of select options
 */
function phptemplate_select($element) {
  if($element['#name'] == 'field_acad_year_id_nid') {
    if(($element['#value'] < 1) || ($element['#value'] == '')) {
      $default_acad_year = variable_get('this_acad_year_nid', '');
      $element['#post']['field_acad_year_id_nid'] = $default_acad_year;
      $element['#value'] = $default_acad_year;
    }
  }

  if(arg(0) == 'pe_programs') {
    if($element['#name'] == 'field_acad_year_id_nid') {
      $element['#attributes'] = array_merge($element['#attributes'],  array('onchange' => "form.submit('views_exposed_form')"));
    }
    // options
    if($element['#name'] == 'field_acad_program_id_nid') {
      $element['#options'] = _get_acad_program_options($element['#post']['field_acad_year_id_nid'], array('All' => '<Any>'));
      $element['#default_value'] = 'All';
    }

    if($element['#name'] == 'acad_year') {
      $element['#attributes'] = array_merge($element['#attributes'],  array('onchange' => "form.submit('views_exposed_form')"));
    }
  }

  $select = '';
  $size = $element['#size'] ? ' size="'. $element['#size'] .'"' : '';
  _form_set_class($element, array('form-select'));
  $multiple = $element['#multiple'];
  return theme('form_element', $element, '<select name="'. $element['#name'] .''. ($multiple ? '[]' : '') .'"'. ($multiple ? ' multiple="multiple" ' : '') . drupal_attributes($element['#attributes']) .' id="'. $element['#id'] .'" '. $size .'>'. form_select_options($element) .'</select>');

}


function _process_fields($view_name, $node, &$fields) {
  global $user;

  if(sizeof($fields) < 2) {
    unset($fields);
    return;
  }

  if($node->type == 'pe_lesson_event') {
    //field_course_id
    $course_id = _get_field_value($node->nid, 'field_course_id', 'pe_lesson_event');
    $field_course_id = $course_id[$node->nid];
    //field_code
    $course_code = _get_field_value($field_course_id, 'field_code', 'pe_course');
    $field_course_code = $course_code[$field_course_id];
    $course_title = $fields['node_title']['data'];
    if(drupal_strlen($field_course_code) > 0) {
      $fields['node_title']['data'] = l($field_course_code, 'node/'. $node->nid, array('title' => $course_title .'('. $field_course_code .')'));
    }
  }

  foreach($node->date_info->date_fields as $val) {
    $val = eregi_replace('\.', '_', $val);
    $substr = substr($val, -6);

    if($substr == '_value') {
      $data_field_key = $val;
      $start_field_key = $val;
      $start = $node->raw->$val;
    } else if($substr == 'value2') {
      $end = $node->raw->$val;
      $end_field_key = $val;
    }

    if(!in_array($fields[$val]['label'], array('starts', 'ends'))) {
      unset($fields[$val]['label']);
    } else {
      unset($fields[$val]['data']);
    }

  }

  if(trim(substr($start, 0, 10)) == trim(substr($end, 0, 10))) {
    $data = '<span class="date-display-single"><span class="date-display-start">'. format_date(strtotime($start), 'custom', 'g:ia') .'</span><span class="date-display-separator"> - </span><span class="date-display-end">'. format_date(strtotime($end), 'custom', 'g:ia') .'</span></span>';
    $fields[$start_field_key]['data'] = $data;
  } else {

    unset($fields[$start_field_key]['data']);
  }

  return $fields;
}

